import React from 'react';

interface IconProps extends React.SVGAttributes<SVGElement> {
    /**
     * Proportionally sets the width and height of the SVG element.
     * To define the width and height manually (not recommended), set to 0.
     * Defaults to 24.
     */
    size?: string | number;
    /**
     * Sets the radius of the background shape in Badge icons.
     * Has no effect on logo icons. Defaults to 12.
     */
    badgeRadius?: number;
}
declare const Icon: React.ForwardRefExoticComponent<IconProps & React.RefAttributes<SVGSVGElement>>;

interface CreateIconOptions {
    /**
     * The `svg` path or group element
     */
    path: React.ReactElement | React.ReactElement[];
    /**
     * The fill of the background rect element. Typically a color or url ID.
     */
    rectFill?: string;
}
/**
 * Convenience function around the Icon component for making icons.
 */
declare function createIcon(options: CreateIconOptions): React.ForwardRefExoticComponent<IconProps & React.RefAttributes<SVGSVGElement>>;

declare const BLThreeP: React.ForwardRefExoticComponent<IconProps & React.RefAttributes<SVGSVGElement>>;

declare const BLThreePBadge: React.ForwardRefExoticComponent<IconProps & React.RefAttributes<SVGSVGElement>>;

declare const Binance: React.ForwardRefExoticComponent<IconProps & React.RefAttributes<SVGSVGElement>>;

declare const BinanceBadge: React.ForwardRefExoticComponent<IconProps & React.RefAttributes<SVGSVGElement>>;

declare const BitMart: React.ForwardRefExoticComponent<IconProps & React.RefAttributes<SVGSVGElement>>;

declare const BitMartBadge: React.ForwardRefExoticComponent<IconProps & React.RefAttributes<SVGSVGElement>>;

declare const Bitbank: React.ForwardRefExoticComponent<IconProps & React.RefAttributes<SVGSVGElement>>;

declare const BitbankBadge: React.ForwardRefExoticComponent<IconProps & React.RefAttributes<SVGSVGElement>>;

declare const Bitfinex: React.ForwardRefExoticComponent<IconProps & React.RefAttributes<SVGSVGElement>>;

declare const BitfinexBadge: React.ForwardRefExoticComponent<IconProps & React.RefAttributes<SVGSVGElement>>;

declare const Bitflyer: React.ForwardRefExoticComponent<IconProps & React.RefAttributes<SVGSVGElement>>;

declare const BitflyerBadge: React.ForwardRefExoticComponent<IconProps & React.RefAttributes<SVGSVGElement>>;

declare const Bithumb: React.ForwardRefExoticComponent<IconProps & React.RefAttributes<SVGSVGElement>>;

declare const BithumbBadge: React.ForwardRefExoticComponent<IconProps & React.RefAttributes<SVGSVGElement>>;

declare const Bitstamp: React.ForwardRefExoticComponent<IconProps & React.RefAttributes<SVGSVGElement>>;

declare const BitstampBadge: React.ForwardRefExoticComponent<IconProps & React.RefAttributes<SVGSVGElement>>;

declare const Bittrex: React.ForwardRefExoticComponent<IconProps & React.RefAttributes<SVGSVGElement>>;

declare const BittrexBadge: React.ForwardRefExoticComponent<IconProps & React.RefAttributes<SVGSVGElement>>;

declare const Bitvavo: React.ForwardRefExoticComponent<IconProps & React.RefAttributes<SVGSVGElement>>;

declare const BitvavoBadge: React.ForwardRefExoticComponent<IconProps & React.RefAttributes<SVGSVGElement>>;

declare const Cex: React.ForwardRefExoticComponent<IconProps & React.RefAttributes<SVGSVGElement>>;

declare const CexBadge: React.ForwardRefExoticComponent<IconProps & React.RefAttributes<SVGSVGElement>>;

declare const ChangellyPro: React.ForwardRefExoticComponent<IconProps & React.RefAttributes<SVGSVGElement>>;

declare const ChangellyProBadge: React.ForwardRefExoticComponent<IconProps & React.RefAttributes<SVGSVGElement>>;

declare const CoinDesk: React.ForwardRefExoticComponent<IconProps & React.RefAttributes<SVGSVGElement>>;

declare const CoinDeskBadge: React.ForwardRefExoticComponent<IconProps & React.RefAttributes<SVGSVGElement>>;

declare const Coinone: React.ForwardRefExoticComponent<IconProps & React.RefAttributes<SVGSVGElement>>;

declare const CoinoneBadge: React.ForwardRefExoticComponent<IconProps & React.RefAttributes<SVGSVGElement>>;

declare const Compound: React.ForwardRefExoticComponent<IconProps & React.RefAttributes<SVGSVGElement>>;

declare const CompoundBadge: React.ForwardRefExoticComponent<IconProps & React.RefAttributes<SVGSVGElement>>;

declare const CryptoCom: React.ForwardRefExoticComponent<IconProps & React.RefAttributes<SVGSVGElement>>;

declare const CryptoComBadge: React.ForwardRefExoticComponent<IconProps & React.RefAttributes<SVGSVGElement>>;

declare const CurrencyCom: React.ForwardRefExoticComponent<IconProps & React.RefAttributes<SVGSVGElement>>;

declare const CurrencyComBadge: React.ForwardRefExoticComponent<IconProps & React.RefAttributes<SVGSVGElement>>;

declare const Curve: React.ForwardRefExoticComponent<IconProps & React.RefAttributes<SVGSVGElement>>;

declare const CurveBadge: React.ForwardRefExoticComponent<IconProps & React.RefAttributes<SVGSVGElement>>;

declare const Digifinex: React.ForwardRefExoticComponent<IconProps & React.RefAttributes<SVGSVGElement>>;

declare const DigifinexBadge: React.ForwardRefExoticComponent<IconProps & React.RefAttributes<SVGSVGElement>>;

declare const Etoro: React.ForwardRefExoticComponent<IconProps & React.RefAttributes<SVGSVGElement>>;

declare const EtoroBadge: React.ForwardRefExoticComponent<IconProps & React.RefAttributes<SVGSVGElement>>;

declare const Ftx: React.ForwardRefExoticComponent<IconProps & React.RefAttributes<SVGSVGElement>>;

declare const FtxBadge: React.ForwardRefExoticComponent<IconProps & React.RefAttributes<SVGSVGElement>>;

declare const GateIo: React.ForwardRefExoticComponent<IconProps & React.RefAttributes<SVGSVGElement>>;

declare const GateIoBadge: React.ForwardRefExoticComponent<IconProps & React.RefAttributes<SVGSVGElement>>;

declare const Gemini: React.ForwardRefExoticComponent<IconProps & React.RefAttributes<SVGSVGElement>>;

declare const GeminiBadge: React.ForwardRefExoticComponent<IconProps & React.RefAttributes<SVGSVGElement>>;

declare const HuobiGlobal: React.ForwardRefExoticComponent<IconProps & React.RefAttributes<SVGSVGElement>>;

declare const HuobiGlobalBadge: React.ForwardRefExoticComponent<IconProps & React.RefAttributes<SVGSVGElement>>;

declare const Indodax: React.ForwardRefExoticComponent<IconProps & React.RefAttributes<SVGSVGElement>>;

declare const IndodaxBadge: React.ForwardRefExoticComponent<IconProps & React.RefAttributes<SVGSVGElement>>;

declare const Kraken: React.ForwardRefExoticComponent<IconProps & React.RefAttributes<SVGSVGElement>>;

declare const KrakenBadge: React.ForwardRefExoticComponent<IconProps & React.RefAttributes<SVGSVGElement>>;

declare const Kucoin: React.ForwardRefExoticComponent<IconProps & React.RefAttributes<SVGSVGElement>>;

declare const KucoinBadge: React.ForwardRefExoticComponent<IconProps & React.RefAttributes<SVGSVGElement>>;

declare const Liquid: React.ForwardRefExoticComponent<IconProps & React.RefAttributes<SVGSVGElement>>;

declare const LiquidBadge: React.ForwardRefExoticComponent<IconProps & React.RefAttributes<SVGSVGElement>>;

declare const Luno: React.ForwardRefExoticComponent<IconProps & React.RefAttributes<SVGSVGElement>>;

declare const LunoBadge: React.ForwardRefExoticComponent<IconProps & React.RefAttributes<SVGSVGElement>>;

declare const Okex: React.ForwardRefExoticComponent<IconProps & React.RefAttributes<SVGSVGElement>>;

declare const OkexBadge: React.ForwardRefExoticComponent<IconProps & React.RefAttributes<SVGSVGElement>>;

declare const Poloniex: React.ForwardRefExoticComponent<IconProps & React.RefAttributes<SVGSVGElement>>;

declare const PoloniexBadge: React.ForwardRefExoticComponent<IconProps & React.RefAttributes<SVGSVGElement>>;

declare const SushiSwap: React.ForwardRefExoticComponent<IconProps & React.RefAttributes<SVGSVGElement>>;

declare const SushiSwapBadge: React.ForwardRefExoticComponent<IconProps & React.RefAttributes<SVGSVGElement>>;

declare const Uniswap: React.ForwardRefExoticComponent<IconProps & React.RefAttributes<SVGSVGElement>>;

declare const UniswapBadge: React.ForwardRefExoticComponent<IconProps & React.RefAttributes<SVGSVGElement>>;

declare const Upbit: React.ForwardRefExoticComponent<IconProps & React.RefAttributes<SVGSVGElement>>;

declare const UpbitBadge: React.ForwardRefExoticComponent<IconProps & React.RefAttributes<SVGSVGElement>>;

declare const WazirX: React.ForwardRefExoticComponent<IconProps & React.RefAttributes<SVGSVGElement>>;

declare const WazirXBadge: React.ForwardRefExoticComponent<IconProps & React.RefAttributes<SVGSVGElement>>;

declare type LogoNames = 'BLThreeP' | 'Binance' | 'BitMart' | 'Bitbank' | 'Bitfinex' | 'Bitflyer' | 'Bithumb' | 'Bitstamp' | 'Bittrex' | 'Bitvavo' | 'Cex' | 'ChangellyPro' | 'CoinDesk' | 'Coinone' | 'Compound' | 'CryptoCom' | 'CurrencyCom' | 'Curve' | 'Digifinex' | 'Etoro' | 'Ftx' | 'GateIo' | 'Gemini' | 'HuobiGlobal' | 'Indodax' | 'Kraken' | 'Kucoin' | 'Liquid' | 'Luno' | 'Okex' | 'Poloniex' | 'SushiSwap' | 'Uniswap' | 'Upbit' | 'WazirX';
declare type BadgeNames = 'BLThreePBadge' | 'BinanceBadge' | 'BitMartBadge' | 'BitbankBadge' | 'BitfinexBadge' | 'BitflyerBadge' | 'BithumbBadge' | 'BitstampBadge' | 'BittrexBadge' | 'BitvavoBadge' | 'CexBadge' | 'ChangellyProBadge' | 'CoinDeskBadge' | 'CoinoneBadge' | 'CompoundBadge' | 'CryptoComBadge' | 'CurrencyComBadge' | 'CurveBadge' | 'DigifinexBadge' | 'EtoroBadge' | 'FtxBadge' | 'GateIoBadge' | 'GeminiBadge' | 'HuobiGlobalBadge' | 'IndodaxBadge' | 'KrakenBadge' | 'KucoinBadge' | 'LiquidBadge' | 'LunoBadge' | 'OkexBadge' | 'PoloniexBadge' | 'SushiSwapBadge' | 'UniswapBadge' | 'UpbitBadge' | 'WazirXBadge';

declare type CryptoconNames = BadgeNames | LogoNames;
interface CryptoconProps extends IconProps {
    icon: CryptoconNames;
}
declare const Cryptocon: React.ForwardRefExoticComponent<CryptoconProps & React.RefAttributes<SVGSVGElement>>;

interface CryptoconBadgeProps extends IconProps {
    icon: BadgeNames;
}
declare const CryptoconBadge: React.ForwardRefExoticComponent<CryptoconBadgeProps & React.RefAttributes<SVGSVGElement>>;

interface CryptoconLogoProps extends Omit<IconProps, 'badgeRadius'> {
    icon: LogoNames;
}
/**
 * A utility component for rendering logo cryptocons with intellisense through the icon property.
 */
declare const CryptoconLogo: React.ForwardRefExoticComponent<CryptoconLogoProps & React.RefAttributes<SVGSVGElement>>;

export { BLThreeP, BLThreePBadge, BadgeNames, Binance, BinanceBadge, BitMart, BitMartBadge, Bitbank, BitbankBadge, Bitfinex, BitfinexBadge, Bitflyer, BitflyerBadge, Bithumb, BithumbBadge, Bitstamp, BitstampBadge, Bittrex, BittrexBadge, Bitvavo, BitvavoBadge, Cex, CexBadge, ChangellyPro, ChangellyProBadge, CoinDesk, CoinDeskBadge, Coinone, CoinoneBadge, Compound, CompoundBadge, CryptoCom, CryptoComBadge, Cryptocon, CryptoconBadge, CryptoconBadgeProps, CryptoconLogo, CryptoconLogoProps, CryptoconNames, CryptoconProps, CurrencyCom, CurrencyComBadge, Curve, CurveBadge, Digifinex, DigifinexBadge, Etoro, EtoroBadge, Ftx, FtxBadge, GateIo, GateIoBadge, Gemini, GeminiBadge, HuobiGlobal, HuobiGlobalBadge, Icon, IconProps, Indodax, IndodaxBadge, Kraken, KrakenBadge, Kucoin, KucoinBadge, Liquid, LiquidBadge, LogoNames, Luno, LunoBadge, Okex, OkexBadge, Poloniex, PoloniexBadge, SushiSwap, SushiSwapBadge, Uniswap, UniswapBadge, Upbit, UpbitBadge, WazirX, WazirXBadge, createIcon };
